@@ -45,12 +45,13 @@ class SslTlsFixture : public SecureFixture {
     return "src/core/tsi/test_creds/server1.key";
   }
 
- private:
+ protected:
   grpc_core::ChannelArgs MutateClientArgs(
       grpc_core::ChannelArgs args) override {
     return args.Set(GRPC_SSL_TARGET_NAME_OVERRIDE_ARG, "foo.test.google.fr");
   }
 
+ private:
   grpc_channel_credentials* MakeClientCreds(
       const grpc_core::ChannelArgs&) override {
     grpc_channel_credentials* ssl_creds =
@@ -102,4 +103,9 @@ class SslTlsFixture : public SecureFixture {
   grpc_tls_version tls_version_;
 };
 
+class SslTlsFixture1_3 : public SslTlsFixture {
+ public:
+  SslTlsFixture1_3() : SslTlsFixture(grpc_tls_version::TLS1_3) {}
+};
+
 #endif  // GRPC_TEST_CORE_END2END_FIXTURES_H2_SSL_TLS_COMMON_H
