@@ -18,7 +18,7 @@
 #include <memory>
 
 #include "absl/functional/any_invocable.h"
-#include "absl/log/check.h"
+#include "absl/log/check.h"  // IWYU pragma: keep
 #include "src/core/lib/iomgr/port.h"
 
 #ifdef GRPC_POSIX_SOCKET_TCP
@@ -26,11 +26,11 @@
 #include "src/core/lib/event_engine/posix_engine/posix_engine.h"
 
 absl::AnyInvocable<
-    std::unique_ptr<grpc_event_engine::experimental::EventEngine>(void)>
+    std::shared_ptr<grpc_event_engine::experimental::EventEngine>(void)>
 CustomEventEngineFactory() {
   return []() {
-    return std::make_unique<
-        grpc_event_engine::experimental::PosixEventEngine>();
+    return grpc_event_engine::experimental::PosixEventEngine::
+        MakePosixEventEngine();
   };
 }
 
