@@ -643,6 +643,13 @@ int main(int argc, char** argv) {
   ::testing::InitGoogleTest(&argc, argv);
   grpc::testing::TestEnvironment env(&argc, argv);
   grpc_init();
+  if (grpc_core::IsEventEngineForAllOtherEndpointsEnabled()) {
+    LOG(INFO) << "This test is skipped since the "
+                 "event_engine_for_all_other_endpoints experiment is enabled, "
+                 "which replaces iomgr grpc_fds with minimal implementations. "
+                 "The test uses grpc_fds directly, which will not work.";
+    return 0;
+  }
   {
     grpc_core::ExecCtx exec_ctx;
     g_pollset = static_cast<grpc_pollset*>(gpr_zalloc(grpc_pollset_size()));
