@@ -55,16 +55,14 @@ class MockEndpoint
       bool, Read,
       (absl::AnyInvocable<void(absl::Status)> on_read,
        grpc_event_engine::experimental::SliceBuffer* buffer,
-       const grpc_event_engine::experimental::EventEngine::Endpoint::ReadArgs*
-           args),
+       grpc_event_engine::experimental::EventEngine::Endpoint::ReadArgs args),
       (override));
 
   MOCK_METHOD(
       bool, Write,
       (absl::AnyInvocable<void(absl::Status)> on_writable,
        grpc_event_engine::experimental::SliceBuffer* data,
-       const grpc_event_engine::experimental::EventEngine::Endpoint::WriteArgs*
-           args),
+       grpc_event_engine::experimental::EventEngine::Endpoint::WriteArgs args),
       (override));
 
   MOCK_METHOD(
@@ -73,6 +71,12 @@ class MockEndpoint
   MOCK_METHOD(
       const grpc_event_engine::experimental::EventEngine::ResolvedAddress&,
       GetLocalAddress, (), (const, override));
+
+  MOCK_METHOD(std::vector<size_t>, AllWriteMetrics, (), (override));
+  MOCK_METHOD(std::optional<absl::string_view>, GetMetricName, (size_t key),
+              (override));
+  MOCK_METHOD(std::optional<size_t>, GetMetricKey, (absl::string_view name),
+              (override));
 };
 
 class MockActivity : public Activity, public Wakeable {
@@ -524,7 +528,8 @@ TEST_F(PromiseEndpointTest, OneWriteSuccessful) {
   EXPECT_CALL(activity, WakeupRequested).Times(0);
   EXPECT_CALL(mock_endpoint_, Write).WillOnce(Return(true));
   auto promise = promise_endpoint_->Write(
-      SliceBuffer(Slice::FromCopiedString("hello world")));
+      SliceBuffer(Slice::FromCopiedString("hello world")),
+      PromiseEndpoint::WriteArgs{});
   auto poll = promise();
   ASSERT_TRUE(poll.ready());
   EXPECT_EQ(absl::OkStatus(), poll.value());
@@ -536,7 +541,8 @@ TEST_F(PromiseEndpointTest, EmptyWriteIsNoOp) {
   activity.Activate();
   EXPECT_CALL(activity, WakeupRequested).Times(0);
   EXPECT_CALL(mock_endpoint_, Write).Times(0);
-  auto promise = promise_endpoint_->Write(SliceBuffer());
+  auto promise =
+      promise_endpoint_->Write(SliceBuffer(), PromiseEndpoint::WriteArgs{});
   auto poll = promise();
   ASSERT_TRUE(poll.ready());
   EXPECT_EQ(absl::OkStatus(), poll.value());
@@ -554,7 +560,8 @@ TEST_F(PromiseEndpointTest, OneWriteFailed) {
             return false;
           }));
   auto promise = promise_endpoint_->Write(
-      SliceBuffer(Slice::FromCopiedString("hello world")));
+      SliceBuffer(Slice::FromCopiedString("hello world")),
+      PromiseEndpoint::WriteArgs{});
   auto poll = promise();
   ASSERT_TRUE(poll.ready());
   EXPECT_EQ(kDummyErrorStatus, poll.value());
@@ -578,7 +585,8 @@ TEST_F(PromiseEndpointTest, OnePendingWriteSuccessful) {
             return false;
           }));
   auto promise = promise_endpoint_->Write(
-      SliceBuffer(Slice::FromCopiedString("hello world")));
+      SliceBuffer(Slice::FromCopiedString("hello world")),
+      PromiseEndpoint::WriteArgs{});
   EXPECT_TRUE(promise().pending());
   // Mock EventEngine write succeeds, and promise resolves.
   write_callback(absl::OkStatus());
@@ -601,7 +609,8 @@ TEST_F(PromiseEndpointTest, OnePendingWriteFailed) {
             return false;
           }));
   auto promise = promise_endpoint_->Write(
-      SliceBuffer(Slice::FromCopiedString("hello world")));
+      SliceBuffer(Slice::FromCopiedString("hello world")),
+      PromiseEndpoint::WriteArgs{});
   EXPECT_TRUE(promise().pending());
   write_callback(kDummyErrorStatus);
   auto poll = promise();
@@ -822,10 +831,12 @@ TEST_F(MultiplePromiseEndpointTest, JoinWritesSuccessful) {
   EXPECT_CALL(on_done, Call(absl::OkStatus()));
   auto activity = MakeActivity(
       [this] {
-        return Seq(Join(this->first_promise_endpoint_.Write(SliceBuffer(
-                            Slice::FromCopiedString("hello world"))),
-                        this->second_promise_endpoint_.Write(SliceBuffer(
-                            Slice::FromCopiedString("hello world")))),
+        return Seq(Join(this->first_promise_endpoint_.Write(
+                            SliceBuffer(Slice::FromCopiedString("hello world")),
+                            PromiseEndpoint::WriteArgs{}),
+                        this->second_promise_endpoint_.Write(
+                            SliceBuffer(Slice::FromCopiedString("hello world")),
+                            PromiseEndpoint::WriteArgs{})),
                    [](std::tuple<absl::Status, absl::Status> ret) {
                      // Both writes finish with `absl::OkStatus`.
                      EXPECT_TRUE(std::get<0>(ret).ok());
@@ -849,10 +860,12 @@ TEST_F(MultiplePromiseEndpointTest, JoinOneWriteSuccessfulOneWriteFailed) {
   EXPECT_CALL(on_done, Call(kDummyErrorStatus));
   auto activity = MakeActivity(
       [this] {
-        return Seq(Join(this->first_promise_endpoint_.Write(SliceBuffer(
-                            Slice::FromCopiedString("hello world"))),
-                        this->second_promise_endpoint_.Write(SliceBuffer(
-                            Slice::FromCopiedString("hello world")))),
+        return Seq(Join(this->first_promise_endpoint_.Write(
+                            SliceBuffer(Slice::FromCopiedString("hello world")),
+                            PromiseEndpoint::WriteArgs{}),
+                        this->second_promise_endpoint_.Write(
+                            SliceBuffer(Slice::FromCopiedString("hello world")),
+                            PromiseEndpoint::WriteArgs{})),
                    [this](std::tuple<absl::Status, absl::Status> ret) {
                      // One write finish with `absl::OkStatus` and the other
                      // write fails.
@@ -883,10 +896,12 @@ TEST_F(MultiplePromiseEndpointTest, JoinWritesFailed) {
   EXPECT_CALL(on_done, Call(kDummyErrorStatus));
   auto activity = MakeActivity(
       [this] {
-        return Seq(Join(this->first_promise_endpoint_.Write(SliceBuffer(
-                            Slice::FromCopiedString("hello world"))),
-                        this->second_promise_endpoint_.Write(SliceBuffer(
-                            Slice::FromCopiedString("hello world")))),
+        return Seq(Join(this->first_promise_endpoint_.Write(
+                            SliceBuffer(Slice::FromCopiedString("hello world")),
+                            PromiseEndpoint::WriteArgs{}),
+                        this->second_promise_endpoint_.Write(
+                            SliceBuffer(Slice::FromCopiedString("hello world")),
+                            PromiseEndpoint::WriteArgs{})),
                    [this](std::tuple<absl::Status, absl::Status> ret) {
                      // Both writes fail with errors.
                      EXPECT_FALSE(std::get<0>(ret).ok());
