@@ -446,75 +446,6 @@ TEST_P(ChannelzServerTest, ManyChannels) {
   EXPECT_EQ(response.channel_size(), kNumChannels);
 }
 
-TEST_P(ChannelzServerTest, ManyRequestsManyChannels) {
-  ResetStubs();
-  const int kNumChannels = 4;
-  ConfigureProxy(kNumChannels);
-  const int kNumSuccess = 10;
-  const int kNumFailed = 11;
-  for (int i = 0; i < kNumSuccess; ++i) {
-    SendSuccessfulEcho(0);
-    SendSuccessfulEcho(2);
-  }
-  for (int i = 0; i < kNumFailed; ++i) {
-    SendFailedEcho(1);
-    SendFailedEcho(2);
-  }
-
-  // the first channel saw only successes
-  {
-    GetChannelRequest request;
-    GetChannelResponse response;
-    request.set_channel_id(GetChannelId(0));
-    ClientContext context;
-    Status s = channelz_stub_->GetChannel(&context, request, &response);
-    EXPECT_TRUE(s.ok()) << "s.error_message() = " << s.error_message();
-    EXPECT_EQ(response.channel().data().calls_started(), kNumSuccess);
-    EXPECT_EQ(response.channel().data().calls_succeeded(), kNumSuccess);
-    EXPECT_EQ(response.channel().data().calls_failed(), 0);
-  }
-
-  // the second channel saw only failures
-  {
-    GetChannelRequest request;
-    GetChannelResponse response;
-    request.set_channel_id(GetChannelId(1));
-    ClientContext context;
-    Status s = channelz_stub_->GetChannel(&context, request, &response);
-    EXPECT_TRUE(s.ok()) << "s.error_message() = " << s.error_message();
-    EXPECT_EQ(response.channel().data().calls_started(), kNumFailed);
-    EXPECT_EQ(response.channel().data().calls_succeeded(), 0);
-    EXPECT_EQ(response.channel().data().calls_failed(), kNumFailed);
-  }
-
-  // the third channel saw both
-  {
-    GetChannelRequest request;
-    GetChannelResponse response;
-    request.set_channel_id(GetChannelId(2));
-    ClientContext context;
-    Status s = channelz_stub_->GetChannel(&context, request, &response);
-    EXPECT_TRUE(s.ok()) << "s.error_message() = " << s.error_message();
-    EXPECT_EQ(response.channel().data().calls_started(),
-              kNumSuccess + kNumFailed);
-    EXPECT_EQ(response.channel().data().calls_succeeded(), kNumSuccess);
-    EXPECT_EQ(response.channel().data().calls_failed(), kNumFailed);
-  }
-
-  // the fourth channel saw nothing
-  {
-    GetChannelRequest request;
-    GetChannelResponse response;
-    request.set_channel_id(GetChannelId(3));
-    ClientContext context;
-    Status s = channelz_stub_->GetChannel(&context, request, &response);
-    EXPECT_TRUE(s.ok()) << "s.error_message() = " << s.error_message();
-    EXPECT_EQ(response.channel().data().calls_started(), 0);
-    EXPECT_EQ(response.channel().data().calls_succeeded(), 0);
-    EXPECT_EQ(response.channel().data().calls_failed(), 0);
-  }
-}
-
 TEST_P(ChannelzServerTest, ManySubchannels) {
   ResetStubs();
   const int kNumChannels = 4;
