@@ -1686,7 +1686,7 @@ TEST_P(ProxyEnd2endTest, ClientCancelsRpc) {
   Status s = stub_->Echo(&context, request, &response);
   cancel_thread.join();
   EXPECT_EQ(StatusCode::CANCELLED, s.error_code());
-  EXPECT_EQ(s.error_message(), "CANCELLED");
+  EXPECT_THAT(s.error_message(), ::testing::HasSubstr("CANCELLED"));
 }
 
 // Server cancels rpc after 1ms
