@@ -676,7 +676,7 @@ TEST_F(OTelTracingTest, PropagationParentToChild) {
 class OTelTracingTestForTransparentRetries : public OTelTracingTest {
  protected:
   void SetUp() override {
-    grpc_core::CoreConfiguration::RegisterBuilder(
+    grpc_core::CoreConfiguration::RegisterEphemeralBuilder(
         [](grpc_core::CoreConfiguration::Builder* builder) {
           // Register FailFirstCallFilter to simulate transparent retries.
           builder->channel_init()->RegisterFilter(
