@@ -14,7 +14,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Generator script for src/core/lib/security/credentials/tls/grpc_tls_credentials_options.h and test/core/security/grpc_tls_credentials_options_comparator_test.cc
+# Generator script for src/core/credentials/transport/tls/grpc_tls_credentials_options.h and test/core/credentials/transport/tls/grpc_tls_credentials_options_comparator_test.cc
 # Should be executed from grpc's root directory.
 
 from __future__ import print_function
@@ -284,9 +284,9 @@ if len(sys.argv) > 1 and sys.argv[1] == "--test":
     test_mode = True
 
 HEADER_FILE_NAME = (
-    "src/core/lib/security/credentials/tls/grpc_tls_credentials_options.h"
+    "src/core/credentials/transport/tls/grpc_tls_credentials_options.h"
 )
-# Generate src/core/lib/security/credentials/tls/grpc_tls_credentials_options.h
+# Generate src/core/credentials/transport/tls/grpc_tls_credentials_options.h
 header_file_name = HEADER_FILE_NAME
 if test_mode:
     header_file_name = tempfile.NamedTemporaryFile(delete=False).name
@@ -298,8 +298,8 @@ print(
     file=H,
 )
 print(
-    """#ifndef GRPC_SRC_CORE_LIB_SECURITY_CREDENTIALS_TLS_GRPC_TLS_CREDENTIALS_OPTIONS_H
-#define GRPC_SRC_CORE_LIB_SECURITY_CREDENTIALS_TLS_GRPC_TLS_CREDENTIALS_OPTIONS_H
+    """#ifndef GRPC_SRC_CORE_CREDENTIALS_TRANSPORT_TLS_GRPC_TLS_CREDENTIALS_OPTIONS_H
+#define GRPC_SRC_CORE_CREDENTIALS_TRANSPORT_TLS_GRPC_TLS_CREDENTIALS_OPTIONS_H
 
 #include <grpc/support/port_platform.h>
 
@@ -309,10 +309,10 @@ print(
 #include <grpc/grpc_security.h>
 
 #include "src/core/util/ref_counted.h"
-#include "src/core/lib/security/credentials/tls/grpc_tls_certificate_distributor.h"
-#include "src/core/lib/security/credentials/tls/grpc_tls_certificate_provider.h"
-#include "src/core/lib/security/credentials/tls/grpc_tls_certificate_verifier.h"
-#include "src/core/lib/security/security_connector/ssl_utils.h"
+#include "src/core/credentials/transport/tls/grpc_tls_certificate_distributor.h"
+#include "src/core/credentials/transport/tls/grpc_tls_certificate_provider.h"
+#include "src/core/credentials/transport/tls/grpc_tls_certificate_verifier.h"
+#include "src/core/credentials/transport/tls/ssl_utils.h"
 
 // Contains configurable options specified by callers to configure their certain
 // security features supported in TLS.
@@ -442,16 +442,14 @@ for data_member in _DATA_MEMBERS:
 print(
     """};
 
-#endif  // GRPC_SRC_CORE_LIB_SECURITY_CREDENTIALS_TLS_GRPC_TLS_CREDENTIALS_OPTIONS_H""",
+#endif  // GRPC_SRC_CORE_CREDENTIALS_TRANSPORT_TLS_GRPC_TLS_CREDENTIALS_OPTIONS_H""",
     file=H,
 )
 
 H.close()
 
-# Generate test/core/security/grpc_tls_credentials_options_comparator_test.cc
-TEST_FILE_NAME = (
-    "test/core/security/grpc_tls_credentials_options_comparator_test.cc"
-)
+# Generate test/core/credentials/transport/tls/grpc_tls_credentials_options_comparator_test.cc
+TEST_FILE_NAME = "test/core/credentials/transport/tls/grpc_tls_credentials_options_comparator_test.cc"
 test_file_name = TEST_FILE_NAME
 if test_mode:
     test_file_name = tempfile.NamedTemporaryFile(delete=False).name
@@ -468,12 +466,11 @@ print(
 
 #include <string>
 
-#include <gmock/gmock.h>
-
 #include <grpc/credentials.h>
 
-#include "src/core/lib/security/credentials/xds/xds_credentials.h"
-#include "src/core/lib/security/credentials/tls/grpc_tls_credentials_options.h"
+#include "gmock/gmock.h"
+#include "src/core/credentials/transport/xds/xds_credentials.h"
+#include "src/core/credentials/transport/tls/grpc_tls_credentials_options.h"
 #include "test/core/test_util/test_config.h"
 
 namespace grpc_core {
