@@ -139,6 +139,8 @@ LANG_RELEASE_MATRIX = {
             ("v1.67.0", ReleaseInfo()),
             ("v1.69.0", ReleaseInfo()),
             ("v1.70.0", ReleaseInfo()),
+            ("v1.71.0", ReleaseInfo()),
+            ("v1.72.0", ReleaseInfo()),
         ]
     ),
     "go": OrderedDict(
@@ -313,6 +315,8 @@ LANG_RELEASE_MATRIX = {
             ("v1.68.2", ReleaseInfo()),
             ("v1.69.4", ReleaseInfo()),
             ("v1.70.0", ReleaseInfo()),
+            ("v1.71.1", ReleaseInfo()),
+            ("v1.72.0", ReleaseInfo()),
         ]
     ),
     "java": OrderedDict(
@@ -461,6 +465,9 @@ LANG_RELEASE_MATRIX = {
             ("v1.67.1", ReleaseInfo()),
             ("v1.68.3", ReleaseInfo()),
             ("v1.69.1", ReleaseInfo()),
+            ("v1.70.0", ReleaseInfo()),
+            ("v1.71.0", ReleaseInfo()),
+            ("v1.72.0", ReleaseInfo()),
         ]
     ),
     "python": OrderedDict(
@@ -843,6 +850,18 @@ LANG_RELEASE_MATRIX = {
                     runtimes=["python"], testcases_file="python__master"
                 ),
             ),
+            (
+                "v1.71.0",
+                ReleaseInfo(
+                    runtimes=["python"], testcases_file="python__master"
+                ),
+            ),
+            (
+                "v1.72.0",
+                ReleaseInfo(
+                    runtimes=["python"], testcases_file="python__master"
+                ),
+            ),
         ]
     ),
     "node": OrderedDict(
@@ -946,6 +965,8 @@ LANG_RELEASE_MATRIX = {
             ("v1.67.0", ReleaseInfo()),
             ("v1.69.0", ReleaseInfo()),
             ("v1.70.0", ReleaseInfo()),
+            ("v1.71.0", ReleaseInfo()),
+            ("v1.72.0", ReleaseInfo()),
         ]
     ),
     "php": OrderedDict(
@@ -1012,6 +1033,8 @@ LANG_RELEASE_MATRIX = {
             ("v1.66.0", ReleaseInfo()),
             ("v1.67.0", ReleaseInfo()),
             ("v1.70.0", ReleaseInfo()),
+            ("v1.71.0", ReleaseInfo()),
+            ("v1.72.0", ReleaseInfo()),
         ]
     ),
     "csharp": OrderedDict(
